@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::Event;
-$XML::Grammar::FictionBase::Event::VERSION = '0.22.5';
+$XML::Grammar::FictionBase::Event::VERSION = '0.22.6';
 
 use strict;
 use warnings;
@@ -32,8 +32,8 @@ sub is_open
 sub is_open_or_close
 {
     my $self = shift;
-
-    return ( ( $self->type() eq "open" ) || ( $self->type() eq "close" ) );
+    my $type = $self->type();
+    return ( ( $type eq "open" ) || ( $type eq "close" ) );
 }
 
 1;
@@ -52,7 +52,7 @@ B<For internal use only>.
 
 =head1 VERSION
 
-version 0.22.5
+version 0.22.6
 
 =head1 SLOTS
 
