@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::FromProto::Parser::XmlIterator;
-$XML::Grammar::FictionBase::FromProto::Parser::XmlIterator::VERSION = '0.22.5';
+$XML::Grammar::FictionBase::FromProto::Parser::XmlIterator::VERSION = '0.22.6';
 use strict;
 use warnings;
 
@@ -727,14 +727,11 @@ sub _look_for_tag_opener
 
     my $l = $self->curr_line_ref();
 
-    if ( $$l =~ m{\G(<(?:/)?)}cg )
+    if ( my ($str) = $$l =~ m{\G(<(?:/)?)}cg )
     {
-        return $1;
-    }
-    else
-    {
-        return;
+        return $str;
     }
+    return;
 }
 
 sub _is_closing_tag
@@ -802,11 +799,7 @@ sub _handle_open_tag
     }
     else
     {
-        my $cb = sub {
-            $self->_push_tag($open);
-        };
-
-        return $cb->();
+        return $self->_push_tag($open);
     }
 }
 
@@ -943,7 +936,7 @@ B<For internal use only>.
 
 =head1 VERSION
 
-version 0.22.5
+version 0.22.6
 
 =head1 SYNOPSIS
 
