@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::TagsTree2XML;
-$XML::Grammar::FictionBase::TagsTree2XML::VERSION = '0.22.5';
+$XML::Grammar::FictionBase::TagsTree2XML::VERSION = '0.22.6';
 use strict;
 use warnings;
 
@@ -65,6 +65,12 @@ has "_writer" => (
     default => sub { return shift->_get_initial_writer(); },
 );
 
+has "_wrote_last" => (
+    'isa'   => "Str",
+    'is'    => "rw",
+    default => "nothing",
+);
+
 sub _get_initial_buffer
 {
     my $buffer = '';
@@ -142,6 +148,7 @@ sub _write_elem
     if ( ref($elem) eq "" )
     {
         $self->_writer->characters($elem);
+        $self->_wrote_last("characters");
     }
     else
     {
@@ -190,6 +197,7 @@ sub _write_Element_Comment
     }
 
     $self->_writer->comment($text);
+    $self->_wrote_last("comment");
 }
 
 sub _calc_write_elem_obj_classes
@@ -269,6 +277,10 @@ sub _write_Element_elem
 
     if ( $elem->_short_isa("InnerDesc") )
     {
+        if ( "endTag" eq $self->_wrote_last() )
+        {
+            $self->_write_elem( { elem => ' ', }, );
+        }
         $self->_output_tag_with_childs(
             {
                 start => ["inlinedesc"],
@@ -328,6 +340,7 @@ sub _handle_elem_of_name_br
     my ( $self, $elem ) = @_;
 
     $self->_writer->emptyTag("br");
+    $self->_wrote_last("endTag");
 
     return;
 }
@@ -343,6 +356,7 @@ sub _output_tag
     $args->{in}->( $self, $args );
 
     $self->_writer->endTag();
+    $self->_wrote_last("endTag");
 }
 
 sub _convert_while_handling_errors
@@ -480,7 +494,7 @@ Internal - (to settle pod-coverage.).
 
 =head1 VERSION
 
-version 0.22.5
+version 0.22.6
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
